@@ -6,6 +6,11 @@ from .exceptions import *
 import numpy as np
 import functools
 
+try:
+    functools.cache
+except AttributeError:
+    functools.cache = functools.lru_cache(None)
+
 if not os.getenv('READTHEDOCS'):
     from patch import p, transform
     from patch.objects import Section
@@ -254,7 +259,7 @@ class NeuronModel:
             import arbor
         except ImportError:
             raise ImportError("`arbor` unavailable, can't make arbor models.")
-        base_cat = arbor.empty_catalogue()
+        base_cat = arbor.catalogue()
         cat = cls._get_catalogue()
         prefix = cls.get_catalogue_prefix()
         base_cat.extend(cat, prefix)
@@ -524,8 +529,15 @@ class NeuronModel:
         decor.paint(f'(region "{label}")', **kwargs)
 
     @classmethod
-    def as_ingredient(cls, name=None, morphology=0, decor=None):
-        from chef import Ingredient, DecorSpy
+    def as_patient(cls, name=None, morphology=0, decor=None):
+        """
+        Gather all information on the model and return it as a
+        :class:`~pesticide.Patient`.
+        """
+        try:
+            from pesticide import Patient, DecorSpy
+        except ImportError:
+            raise ImportError("Install `dev` requirements.")
         import arbor
 
         if name is None:
@@ -534,7 +546,7 @@ class NeuronModel:
             decor = DecorSpy()
         cat = cls.get_catalogue()
         morph, labels, decor = cls._cable_cell(morphology, decor)
-        return Ingredient(name, cat, morph, labels, decor)
+        return Patient(name, cat, morph, labels, decor)
 
 
 def _try_mech_presence(mech, resolved):
